@@ -1,14 +1,18 @@
 import fnmatch
 import re
-from typing import Any, Set
+from typing import Set, Container, Mapping, Any, Sized, Iterable, Tuple
 
 from pybeandi.errors import NoSuchBeanError, MultipleBeanInstancesError, \
     BeanIdAlreadyExistsError
 from pybeandi.model import WildcardBeanRef, IdBeanRef, UserGeneralBeanRef, \
-    RegexBeanRef
+    RegexBeanRef, BeanId, BeanInstance
 
 
-class BeansList:
+class BeansList(
+    Mapping[UserGeneralBeanRef, BeanInstance],
+    Sized,
+    Iterable[Tuple[BeanId, BeanInstance]],
+):
     """
     Readonly dictionary-like object to access beans
     """
@@ -18,9 +22,10 @@ class BeansList:
             beans = {}
         self._beans = beans
 
-    def get_bean_by_id(self, bean_id: str) -> Any:
+    def get_bean_by_id(self, bean_id: BeanId) -> BeanInstance:
         """
         Return bean from context by its id
+
         @param bean_id: id of bean
         @return: bean
         @raise NoSuchBeanError: if such bean does not exist
@@ -29,25 +34,28 @@ class BeansList:
             raise NoSuchBeanError(f'Bean with id \'{bean_id}\' does not exist')
         return self._beans[bean_id]
 
-    def get_beans_by_wildcard(self, wildcard: str) -> Set[Any]:
+    def get_beans_by_wildcard(self, wildcard: str) -> Set[BeanInstance]:
         needed_ids = fnmatch.filter(self.ids(), wildcard)
         return {self[bean_id] for bean_id in needed_ids}
 
-    def get_beans_by_regex(self, regex: str) -> Set[Any]:
+    def get_beans_by_regex(self, regex: str) -> Set[BeanInstance]:
         needed_ids = (bean_id for bean_id in self.ids()
                       if re.match(regex, bean_id))
         return {self[bean_id] for bean_id in needed_ids}
 
-    def _add_as_bean(self, bean_id: str, obj: Any) -> None:
+    def _add_as_bean(
+            self, bean_id: BeanId, bean_instance: BeanInstance
+    ) -> None:
         """
         Register obj as bean
+
         @param bean_id: id of new bean
-        @param obj: object to register as a bean
+        @param bean_instance: object to register as a bean
         """
         if bean_id in self._beans:
             raise BeanIdAlreadyExistsError(
                 f'Bean with id \'{bean_id}\' already exists')
-        self._beans[bean_id] = obj
+        self._beans[bean_id] = bean_instance
 
     def values(self):
         return self._beans.values()
@@ -58,9 +66,10 @@ class BeansList:
     def items(self):
         return self._beans.items()
 
-    def __contains__(self, bean_ref: UserGeneralBeanRef):
+    def __contains__(self, bean_ref: Any):
         """
         Checks do bean exists by its reference
+
         @param bean_ref: reference
         @return: do bean exists
         """
@@ -73,20 +82,21 @@ class BeansList:
             return True
         return True
 
-    def __getitem__(self, bean_ref: UserGeneralBeanRef) -> Any:
+    def __getitem__(self, bean_ref: UserGeneralBeanRef) -> BeanInstance:
         """
         General method that returns beans by any type of reference
         (id, BeanRef instance)
-        :param bean_ref: id or BeanRef instance
-        :return: bean or set of beans, depends on :bean_ref:
+
+        @param bean_ref: id or BeanRef instance
+        @return: bean or set of beans, depends on :bean_ref: type
         """
-        if type(bean_ref) is str:
+        if isinstance(bean_ref, BeanId):
             return self.get_bean_by_id(bean_ref)
-        if type(bean_ref) is IdBeanRef:
+        if isinstance(bean_ref, IdBeanRef):
             return self.get_bean_by_id(bean_ref.bean_id)
-        if type(bean_ref) is WildcardBeanRef:
+        if isinstance(bean_ref, WildcardBeanRef):
             return self.get_beans_by_wildcard(bean_ref.wildcard)
-        if type(bean_ref) is RegexBeanRef:
+        if isinstance(bean_ref, RegexBeanRef):
             return self.get_beans_by_regex(bean_ref.regex)
         raise ValueError(f'Invalid bean reference {bean_ref}')
 
