@@ -1,4 +1,5 @@
 import inspect
+from pathlib import Path
 from types import ModuleType
 from typing import Dict, Any, Callable, Type, Set, List
 
@@ -8,19 +9,25 @@ from pybeandi.beans_list import BeansList
 from pybeandi.config import Configuration
 from pybeandi.decorators import BeanMeta, AfterInitMeta
 from pybeandi.errors import ContextInitError
-from pybeandi.model import BeanDef, id_ref, UserGeneralBeanRef
+from pybeandi.model import (
+    BeanDef, id_ref, UserGeneralBeanRef, BeanId, BeanInstance
+)
 from pybeandi.util import setup_yaml_env_vars, all_callable_of_object
 
 
 class BeanContext:
-    bean_defs: Dict[str, BeanDef]
+    """
+    Main class of pybeandi.
+    Links all beans to each other and controls theirs lifecycle
+    """
+    bean_defs: Dict[BeanId, BeanDef]
     beans: BeansList
     profiles: Set[str]
 
     closed: bool = False
 
-    def __init__(self, bean_defs: Dict[str, BeanDef], profiles: Set[str]):
-        self._bean_defs: Dict[str, BeanDef] = bean_defs
+    def __init__(self, bean_defs: Dict[BeanId, BeanDef], profiles: Set[str]):
+        self._bean_defs: Dict[BeanId, BeanDef] = bean_defs
         self._beans: BeansList = BeansList()
         self._profiles = profiles
 
@@ -35,6 +42,7 @@ class BeanContext:
     def init(self) -> None:
         """
         Initialize context using bean definitions provided earlier
+
         @raise ContextInitError: is context incorrect
         """
         self._bean_defs = {bean_id: bean_def for (bean_id, bean_def) in
@@ -48,16 +56,19 @@ class BeanContext:
                                       self._bean_defs.items()
                                       if bean_id not in self.beans]
             # Filter all beans with unsatisfied dependencies
-            to_init = [bean_def
-                       for bean_def in to_init
-                       if all(
-                    dep_ref.all_dependencies_satisfied(self.beans.ids(),
-                                                       all_beans_ids)
-                    for dep_ref in bean_def.dependencies.values())]
+            to_init = [
+                bean_def for bean_def in to_init
+                if all(
+                    dep_ref.all_dependencies_satisfied(
+                        self.beans.ids(), all_beans_ids
+                    ) for dep_ref in bean_def.dependencies.values()
+                )
+            ]
 
             if len(to_init) == 0:
                 raise ContextInitError(
-                    f'Circular or missing dependency was founded')
+                    'Circular or missing dependency was founded'
+                )
 
             for bean_def in to_init:
                 beans_to_insert = {arg_name: self.beans[arg_bean_ref]
@@ -95,12 +106,21 @@ class BeanContext:
 
 
 class BeanContextBuilder:
+    """
+    Builder for BeanContext
+    """
     def __init__(self):
         self._scanned: Set = set()
         self.bean_defs: List[BeanDef] = []
         self.profiles = set()
 
     def init(self) -> BeanContext:
+        """
+        Create BeanContext from defined settings
+
+        @raise ContextInitError: context configuration error
+        @return: BeanContext
+        """
         # Check id duplication
         bean_defs = [bean_def for bean_def in self.bean_defs
                      if bean_def.profile_func(self.profiles)]
@@ -119,23 +139,29 @@ class BeanContextBuilder:
         return ctx
 
     def load_config(self, config: Configuration):
+        """
+        Loads config to builder. Usually it's used inside lib
+
+        @param config: Configuration object
+        """
         if config.profiles is not None:
             if not all(profile in self.profiles
                        for profile in config.profiles):
                 return
         if config.beans is not None:
-            for bean_id, bean_obj in config.beans.items():
-                self.add_as_bean(bean_id, bean_obj)
+            for bean_id, bean_instance in config.beans.items():
+                self.add_as_bean(bean_id, bean_instance)
 
-    def load_yaml(self, file_path: str) -> None:
+    def load_yaml(self, path: Path) -> None:
         """
         Load configuration from specified file
-        @param file_path: YAML config file
+
+        @param path: YAML config file
         """
 
         loader = setup_yaml_env_vars(yaml.SafeLoader)
 
-        with open(file_path, 'r', encoding='utf-8') as file:
+        with open(path, 'r', encoding='utf-8') as file:
             for yaml_raw in yaml.load_all(file, loader):
                 if 'pybeandi' not in yaml_raw:
                     return
@@ -146,9 +172,11 @@ class BeanContextBuilder:
 
     def import_module(self, module: ModuleType):
         """
-        Imports all declared beans from module
-        :param module: module with beans
-        (usually module is import <module_name> object)
+        Imports all declared beans from module.
+        (usually module is 'import <module_name>' object
+        or sys.modules[__name__])
+
+        @param module: module with beans
         """
         for name, member in inspect.getmembers(
                 module,
@@ -161,13 +189,14 @@ class BeanContextBuilder:
             self.register_bean_by_class(member)
 
     def register_bean(self,
-                      bean_id: str,
+                      bean_id: BeanId,
                       factory_func: Callable[..., Any],
                       dependencies: Dict[str, UserGeneralBeanRef],
                       profile_func: Callable[[Set[str]], bool]
                       = lambda profs: True) -> None:
         """
         Register bean to be created at init phase
+
         @param bean_id: id of registered bean
         @param factory_func: function or class that returns object of bean
         @param dependencies: dictionary of names of factory_func arg to
@@ -176,7 +205,11 @@ class BeanContextBuilder:
         bean
         """
         dependencies = {
-            arg_name: (id_ref(arg_ref) if type(arg_ref) is str else arg_ref)
+            arg_name: (
+                id_ref(arg_ref)
+                if isinstance(arg_ref, BeanId)
+                else arg_ref
+            )
             for (arg_name, arg_ref) in dependencies.items()}
 
         self.bean_defs.append(
@@ -184,8 +217,9 @@ class BeanContextBuilder:
 
     def register_bean_by_class(self, cls: Type) -> None:
         """
-        Register bean to be created at init phase by class
+        Register bean to be created at init phase by class.
         Class must be decorated by @bean first!
+
         @param cls: class of bean
         """
         bean_meta: BeanMeta = cls._bean_meta
@@ -197,5 +231,11 @@ class BeanContextBuilder:
             bean_meta.profile_func
         )
 
-    def add_as_bean(self, bean_id: str, bean_obj: Any):
-        self.register_bean(bean_id, lambda: bean_obj, {})
+    def add_as_bean(self, bean_id: BeanId, bean_instance: BeanInstance):
+        """
+        Add object as a simple bean (without dependencies). Useful for configs
+
+        @param bean_id: bean id
+        @param bean_instance: object
+        """
+        self.register_bean(bean_id, lambda: bean_instance, {})
