@@ -1,4 +1,4 @@
-class BeanFindingError(RuntimeError):
+class BeanFindingError(Exception):
     pass
 
 
@@ -10,9 +10,9 @@ class MultipleBeanInstancesError(BeanFindingError):
     pass
 
 
-class BeanIdAlreadyExistsError(RuntimeError):
+class BeanIdAlreadyExistsError(Exception):
     pass
 
 
-class ContextInitError(RuntimeError):
+class ContextInitError(Exception):
     pass
