@@ -2,7 +2,7 @@ import pytest
 
 from pybeandi.context import BeanContextBuilder
 from pybeandi.errors import NoSuchBeanError, ContextInitError
-from pybeandi.model import id_ref, wildcard_ref, regex_ref
+from pybeandi.model import id_ref, wildcard_ref, regex_ref, BeanId
 from pybeandi.test import beans_with_inject
 from pybeandi.test.beans_with_inject import ClassInjectBean
 from pybeandi.test.conftest import ClassBasedBean
@@ -17,7 +17,7 @@ def test_init(ctx_builder: BeanContextBuilder):
 def test_init_with_duplicates(ctx_builder: BeanContextBuilder):
     ctx_builder.add_as_bean('1', -1)
     with pytest.raises(ContextInitError):
-        with ctx_builder.init() as ctx:
+        with ctx_builder.init():
             pass
 
 
@@ -25,14 +25,16 @@ def test_init_inject_class(ctx_builder: BeanContextBuilder):
     ctx_builder.profiles.add('class_based')
     ctx_builder.import_module(beans_with_inject)
     with ctx_builder.init() as ctx:
-        assert type(ctx.beans[id_ref('bean_with_inject')]) is ClassInjectBean
+        assert isinstance(
+            ctx.beans[id_ref('bean_with_inject')], ClassInjectBean
+        )
 
 
 def test_init_inject_func(ctx_builder: BeanContextBuilder):
     ctx_builder.profiles.add('func_based')
     ctx_builder.import_module(beans_with_inject)
     with ctx_builder.init() as ctx:
-        assert type(ctx.beans[id_ref('bean_with_inject')]) is str
+        assert isinstance(ctx.beans[id_ref('bean_with_inject')], BeanId)
 
 
 def test_init_inject_manual(ctx_builder: BeanContextBuilder):
@@ -50,14 +52,15 @@ def test_init_inject_manual(ctx_builder: BeanContextBuilder):
     )
     with ctx_builder.init() as ctx:
         assert ctx.beans[id_ref('manual_inject')] == (
-        1, {1, 2, 3}, {1, 2, 3}, None)
+            1, {1, 2, 3}, {1, 2, 3}, None
+        )
 
 
 def test_multiple_module_import(ctx_builder: BeanContextBuilder):
     ctx_builder.profiles.add('class_based')
     ctx_builder.import_module(beans_with_inject)
     ctx_builder.import_module(beans_with_inject)
-    with ctx_builder.init() as ctx:
+    with ctx_builder.init():
         pass
 
 
@@ -66,11 +69,15 @@ def test_id_ref(ctx_builder: BeanContextBuilder):
         assert ctx.beans[id_ref('1')] == ctx.beans['1'] == 1
         assert ctx.beans[id_ref('2')] == ctx.beans['2'] == 2
         assert ctx.beans[id_ref('3')] == ctx.beans['3'] == 3
-        assert type(ctx.beans[id_ref('class_based_bean')]) is ClassBasedBean
-        assert type(ctx.beans[id_ref('func_based_bean')]) is str
+        assert isinstance(
+            ctx.beans[id_ref('class_based_bean')], ClassBasedBean
+        )
+        assert isinstance(
+            ctx.beans[id_ref('func_based_bean')], BeanId
+        )
 
         with pytest.raises(NoSuchBeanError):
-            empty = ctx.beans['empty']
+            empty = ctx.beans['empty']  # noqa F841
 
         assert '1' in ctx.beans and id_ref('1') in ctx.beans
         assert '2' in ctx.beans and id_ref('2') in ctx.beans
@@ -87,10 +94,10 @@ def test_wildcard_ref(ctx_builder: BeanContextBuilder):
         assert ctx.beans[wildcard_ref('[123]')] == {1, 2, 3}
         assert ctx.beans[wildcard_ref('[13]')] == {1, 3}
         assert ctx.beans[wildcard_ref('empty')] == set()
-        assert {type(bean) for bean in
-                ctx.beans[wildcard_ref('class_based_*')]} == {ClassBasedBean}
-        assert {type(bean) for bean in
-                ctx.beans[wildcard_ref('func_based_*')]} == {str}
+        for bean in ctx.beans[wildcard_ref('class_based_*')]:
+            assert isinstance(bean, ClassBasedBean)
+        for bean in ctx.beans[wildcard_ref('func_based_*')]:
+            assert isinstance(bean, BeanId)
 
 
 def test_regex_ref(ctx_builder: BeanContextBuilder):
@@ -98,10 +105,10 @@ def test_regex_ref(ctx_builder: BeanContextBuilder):
         assert ctx.beans[regex_ref(r'^[1-3]$')] == {1, 2, 3}
         assert ctx.beans[regex_ref(r'^[13]$')] == {1, 3}
         assert ctx.beans[regex_ref(r'empty')] == set()
-        assert {type(bean) for bean in
-                ctx.beans[regex_ref(r'class_based_.+')]} == {ClassBasedBean}
-        assert {type(bean) for bean in
-                ctx.beans[regex_ref(r'func_based_.+')]} == {str}
+        for bean in ctx.beans[regex_ref(r'class_based_.+')]:
+            assert isinstance(bean, ClassBasedBean)
+        for bean in ctx.beans[regex_ref(r'func_based_.+')]:
+            assert isinstance(bean, BeanId)
 
 
 def test_optional_without_bean(ctx_builder: BeanContextBuilder):
