@@ -3,8 +3,6 @@ import os
 import re
 from typing import Any, Callable, Generator
 
-import yaml
-
 
 def camel_case_to_snake_case(camel_case: str) -> str:
     """
@@ -52,5 +50,11 @@ def setup_yaml_env_vars(base_loader, tag='!ENV'):
     return base_loader
 
 
-def all_callable_of_object(obj: Any) -> Generator[Callable, Any, None]:
-    return (func for (name, func) in inspect.getmembers(obj, inspect.ismethod))
+def all_callable_of_object(obj: Any) -> Generator[Callable, None, None]:
+    """
+    Yields all methods of object
+    @param obj:
+    @return:
+    """
+    for name, func in inspect.getmembers(obj, inspect.ismethod):
+        yield func
